@@ -22,7 +22,7 @@ def save_to_config(db_config: dict, report_to_dashboard=False):
     config.set('database', 'password', db_config['password'])
     config.set('database', 'database', db_config['database'])
 
-    with open('simple_async_mq_server/config.ini', 'w') as configfile:
+    with open('simple_async_mq_server/config.ini', 'w+') as configfile:
         config.write(configfile)
 
 if __name__ == '__main__':
